/******** <lalVerbatim file="BlockBuildOutputCV"> ********
Author: Tibbits, M. M.
$Id: BlockBuildOutput.c,v 1.2 2002/07/05 20:52:10 tibbits Exp $
********* </lalVerbatim> ********/

/******************************* <lalLaTeX file="BlockBuildOutputC">
\subsection{Module \texttt{BlockBuildOutput.c}}
\label{s:BlockBuildOutput.c}

Routine that builds the output from the result vector stored in the
parameter structure for insertion into the metadata database and frames.

\subsubsection*{Prototypes}
\input{BlockBuildOutputCP}
\index{\texttt{BlockBuildOutput()}}

\subsection*{Description}

Routine that builds the output from the result vector stored in the
parameter structure for insertion into the metadata database and frames.


\subsection*{Tables Used}

\begin{itemize}
\item \texttt{search::summary}
\item \texttt{summ::value}
\end{itemize}

\subsection*{Uses}
 
\begin{itemize}
\item \texttt{LALMalloc}
\item \texttt{LALCalloc}
\end{itemize}

\subsection*{Notes}

\vfill{\footnotesize\input{BlockBuildOutputCV}}

*************************************************** </lalLaTeX> */

#include "BlockApplySearch.h"
#include "BlockBuildOutput.h"

NRCSID( BLOCKBUILDOUTPUTC, "$Id: BlockBuildOutput.c,v 1.2 2002/07/05 20:52:10 tibbits Exp $");

/************************ <lalVerbatim file="BlockBuildOutputCP"> */
void BuildOutput
(
	LALStatus		*status,
	LALSearchOutput		*output,
	BlockSearchParams	*params
)
/*********************************************** </lalVerbatim> */
{
	dataBase	*dbEntry	= NULL;
	outPut		*outputPtr	= NULL;
const	CHAR		*PROGRAM	= "Block Normal Search";

	INITSTATUS( status, "BlockBuildOutput", BLOCKBUILDOUTPUTC );

	output->numOutput = 2;

	/*  Allocate Memory  */
	output->result = outputPtr = LALMalloc( (output->numOutput) * sizeof(outPut) );
	if ( !output->result )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	outputPtr[0].indexNumber	= 0;
	outputPtr[0].search		= experimental;
	outputPtr[0].significant	= 1;	/* 1 - IS significant */
	outputPtr[0].states		= 0;
	outputPtr[0].optional		= 0;

	/*
	 * Start a linked list of database entries - the head of the list
	 * starts with the "results" field
	 */

	outputPtr[0].results = dbEntry = LALCalloc(1, sizeof(dataBase));
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	dbEntry->previous = 0;



	/* Shared Object Name */
	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "shared_object", dbNameLimit );

	dbEntry->type		= char_s_ptr;
	dbEntry->numberRows	= 1;

	dbEntry->rows.chars = LALMalloc(sizeof(CHAR)*(strlen(PROGRAM) + 1) );
	strcpy(dbEntry->rows.chars, PROGRAM);

	dbEntry->rowDimensions = LALMalloc(sizeof(UINT4));

	/* Don't include terminating null */
	dbEntry->rowDimensions[0] = strlen(PROGRAM);

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;

        if ( !dbEntry )
	{
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}


	/* LAL CVS tag */
	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "lal_cvs_tag", dbNameLimit );

	dbEntry->type		= char_s_ptr;
	dbEntry->numberRows	= 1;

	dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen(LAL_CVS_TAG)+1) * sizeof(CHAR) );
	if ( !dbEntry->rows.chars )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strcpy( dbEntry->rows.chars, LAL_CVS_TAG);

	dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
	if ( !dbEntry->rowDimensions )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rowDimensions) = strlen(LAL_CVS_TAG);

        dbEntry->next = LALCalloc(1, sizeof(dataBase));
        dbEntry->next->previous = dbEntry;
        dbEntry = dbEntry->next;

        if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}


	/* LALWrapper CVS tag */
	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "lalwrapper_cvs_tag", dbNameLimit );

	dbEntry->type		= char_s_ptr;
	dbEntry->numberRows	= 1;

	dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen(LAL_WRAPPER_CVS_TAG)+1) * sizeof(CHAR) );
	if ( !dbEntry->rows.chars )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strcpy( dbEntry->rows.chars, LAL_WRAPPER_CVS_TAG);

	dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
	if ( !dbEntry->rowDimensions )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rowDimensions) = strlen(LAL_WRAPPER_CVS_TAG);

        dbEntry->next = LALCalloc(1, sizeof(dataBase));
        dbEntry->next->previous = dbEntry;
        dbEntry = dbEntry->next;

        if ( !dbEntry )
	{
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/* In Start time */
	strncpy( dbEntry->tableName, "search_summary", dbNameLimit);
	strncpy( dbEntry->columnName, "in_start_time", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

	*(dbEntry->rows.int4s) = params->times.startSec;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
        if ( !dbEntry )
        {                
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }


	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "in_start_time_ns", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );

	*(dbEntry->rows.int4s) = params->times.startNan;
	dbEntry->rowDimensions = NULL;
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  In End time  */
	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "in_end_time", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

	*(dbEntry->rows.int4s) = params->times.stopSec;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
        if ( !dbEntry )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

	strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
	strncpy( dbEntry->columnName, "in_end_time_ns", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }


	*(dbEntry->rows.int4s) = params->times.stopNan;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
        if ( !dbEntry )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }



        /* Out Start time */
        strncpy( dbEntry->tableName, "search_summary", dbNameLimit);
        strncpy( dbEntry->columnName, "out_start_time", dbNameLimit );

        dbEntry->type       = int_4s;
        dbEntry->numberRows = 1;
        dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        *(dbEntry->rows.int4s) = params->times.startSec;
        dbEntry->rowDimensions = NULL;

        dbEntry->next = LALCalloc(1, sizeof(dataBase));
        dbEntry->next->previous = dbEntry;
        dbEntry = dbEntry->next;
        if ( !dbEntry )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
        strncpy( dbEntry->columnName, "out_start_time_ns", dbNameLimit );

        dbEntry->type       = int_4s;
        dbEntry->numberRows = 1;
        dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        *(dbEntry->rows.int4s) = params->times.startNan;
        dbEntry->rowDimensions = NULL;

        dbEntry->next = LALCalloc(1, sizeof(dataBase));
        dbEntry->next->previous = dbEntry;
        dbEntry = dbEntry->next;
        if ( !dbEntry )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }



        /* Out End time */
        strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
        strncpy( dbEntry->columnName, "out_end_time", dbNameLimit );

        dbEntry->type       = int_4s;
        dbEntry->numberRows = 1;
        dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        *(dbEntry->rows.int4s) = params->times.stopSec;
        dbEntry->rowDimensions = NULL;

        dbEntry->next = LALCalloc(1, sizeof(dataBase));
        dbEntry->next->previous = dbEntry;
        dbEntry = dbEntry->next;
        if ( !dbEntry )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        strncpy( dbEntry->tableName, "search_summary", dbNameLimit );
        strncpy( dbEntry->columnName, "out_end_time_ns", dbNameLimit );

        dbEntry->type       = int_4s;
        dbEntry->numberRows = 1;
        dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
        if ( !dbEntry->rows.int4s )
        {
                ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
        }

        *(dbEntry->rows.int4s) = params->times.stopNan;
        dbEntry->rowDimensions = NULL;

        /* Terminate the list */
        dbEntry->next = 0;

	if ( params->resultsToStore )
	{
		outputPtr[1].indexNumber	= 0;
		outputPtr[1].search		= experimental;
		outputPtr[1].significant	= 1;    /* 1 - IS significant */
		outputPtr[1].states		= 0;
		outputPtr[1].optional		= 0;

		outputPtr[1].results = params->resultsToStore;

		params->resultsToStore = NULL;
	}

	RETURN(status);
}


/************************ <lalVerbatim file="BlockBuildOutputCP"> */
void AddResults
(
	LALStatus		*status,
	LALSearchOutput		*output,
	INT4			idToStore,
	BlockSearchParams	*params
)
/*********************************************** </lalVerbatim> */
{
	dataBase	*dbEntry = NULL;

	INITSTATUS( status, "AddResults", BLOCKBUILDOUTPUTC );

	if ( params->resultsToStore )
	{
		params->prevResult->next = dbEntry = LALCalloc(1, sizeof(dataBase));
		dbEntry->previous = params->prevResult;
	}
	else
	{
		params->resultsToStore = dbEntry = LALCalloc(1, sizeof(dataBase));
		params->resultsToStore->previous = 0;
	}

	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Version == sequence number in Data stream - see Doc.  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "version", dbNameLimit );

	dbEntry->type		= int_4s;
	dbEntry->numberRows	= 1;
	dbEntry->rows.int4s	= LALMalloc( sizeof(INT4) );

	*(dbEntry->rows.int4s)	= params->run;
	dbEntry->rowDimensions	= NULL;
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;

	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Program Field  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "program", dbNameLimit );

	dbEntry->type           = char_s_ptr;
	dbEntry->numberRows     = 1;

	dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen("Block Search")+1) * sizeof(CHAR) );
	if ( !dbEntry->rows.chars )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strcpy( dbEntry->rows.chars, "Block Search");
	dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
	if ( !dbEntry->rowDimensions )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rowDimensions) = strlen("Block Search");

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  ifo Field  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "ifo", dbNameLimit );

	dbEntry->type           = char_s_ptr;
	dbEntry->numberRows     = 1;

	dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen("H2")) * sizeof(CHAR) );
	if ( !dbEntry->rows.chars )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strncpy( dbEntry->rows.chars, "H2",2);
	dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
	if ( !dbEntry->rowDimensions )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rowDimensions) = strlen("H2");

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/* Start time */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit);
	strncpy( dbEntry->columnName, "start_time", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.int4s) = params->times.startSec;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "start_time_ns", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );

	*(dbEntry->rows.int4s) = params->times.startNan;
	dbEntry->rowDimensions = NULL;
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  End time  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "end_time", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.int4s) = params->times.stopSec;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "end_time_ns", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.int4s) = params->times.stopNan;
	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Name Field  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "name", dbNameLimit );

	dbEntry->type           = char_s_ptr;
	dbEntry->numberRows     = 1;

	dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen("Max Point in Data Set")+1) * sizeof(CHAR) );
	if ( !dbEntry->rows.chars )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	strcpy( dbEntry->rows.chars, "Max Point in Data Set");
	dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
	if ( !dbEntry->rowDimensions )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rowDimensions) = strlen("Max Point in Data Set");

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Value Field - Max Data Point  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit);
	strncpy( dbEntry->columnName, "value", dbNameLimit );

	dbEntry->type       = real_4;
	dbEntry->numberRows = 1;
	dbEntry->rows.real4 = LALMalloc( sizeof(REAL4) );
	if ( !dbEntry->rows.real4 )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.real4) = (REAL4)(log(params->value->data[idToStore]));

	if ( *(dbEntry->rows.real4) > 10000 )
		*(dbEntry->rows.real4) = -1;

	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Index of Max Value  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit );
	strncpy( dbEntry->columnName, "intvalue", dbNameLimit );

	dbEntry->type       = int_4s;
	dbEntry->numberRows = 1;
	dbEntry->rows.int4s = LALMalloc( sizeof(INT4) );
	if ( !dbEntry->rows.int4s )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.int4s) = params->ndx->data[idToStore];

	dbEntry->rowDimensions = NULL;

	dbEntry->next = LALCalloc(1, sizeof(dataBase));
	dbEntry->next->previous = dbEntry;
	dbEntry = dbEntry->next;
	if ( !dbEntry )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}



	/*  Rho2 Value of Segment  */
	strncpy( dbEntry->tableName, "summ_value", dbNameLimit);
	strncpy( dbEntry->columnName, "error", dbNameLimit );

	dbEntry->type       = real_4;
	dbEntry->numberRows = 1;
	dbEntry->rows.real4 = LALMalloc( sizeof(REAL4));
	if ( !dbEntry->rows.real4 )
	{
		ABORT (status, BLOCKAPPLYSEARCHH_EALOC, BLOCKAPPLYSEARCHH_MSGEALOC);
	}

	*(dbEntry->rows.real4) = (REAL4)(log(params->res->data[idToStore]));

	if ( *(dbEntry->rows.real4) > 10000  )
		*(dbEntry->rows.real4) = -1;

	dbEntry->rowDimensions = NULL;

	dbEntry->next = 0;

	params->prevResult = dbEntry;

	RETURN(status);
}
