/******** <lalVerbatim file="MatrixDivideCV"> ********
Author: Tibbits, M. M.
$Id: MatrixDivide.m4,v 1.1 2002/07/05 20:53:50 tibbits Exp $
********* </lalVerbatim> ********/

/******************************* <lalLaTeX file="MatrixDivideC">
\section{Module \texttt{MatrixDivide.c}}
\label{s:MatrixDivide.c}

This file is dedicated to reproducing the matlab function " ./ ".  This file
has several declarations of the same function taking all forms of available
input.  This being said, I have yet to script the complex actions and their
counterparts.

\subsection*{Description}

This file is to help make the conversion from Matlab to c much earier.
In this file, we have created all of the versions of ./ that we plan on
using.

\subsection*{Algorithms}

The algorithm is the same as it is in matlab.  The dot in front of an operator
in matlab signifies that if either or both of the operands are vectors, then
the operation will be carried out member by member.  For instance

vector a[25];
vector b[25];
vector c[25];

c = a ./ b;

The result of this is:

c[0] =	a[0] /	b[0];
c[1] =	a[1] /	b[1];
.	.	.
.	.	.
.	.	.

etc.

\subsection*{Uses}
 
\begin{itemize}
\item \texttt{LALDCreateVector}
\end{itemize}

\subsection*{Notes}

At the current time none of the operations have been specified for neither the
complex datatypes nor the unsigned datatypes.

\subsubsection*{Prototypes}

 *************************************************** </lalLaTeX> */


#include <math.h>
#include "Matrix.h"

NRCSID( MATLABMATRIXDIVC, "$Id: MatrixDivide.m4,v 1.1 2002/07/05 20:53:50 tibbits Exp $");
























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashDVector ( LALStatus *status, REAL8Vector **result,
		REAL8 A, REAL8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashDVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8			A,
        REAL8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotSlashDVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashD ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashD (
        LALStatus               *status,
        REAL8Vector          **result,
        REAL8Vector          *A,
        REAL8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashD" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashDVector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, REAL8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashDVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        REAL8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashDVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashDArray ( LALStatus *status, REAL8Array **result,
		REAL8 A, REAL8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashDArray (
        LALStatus               *status,
        REAL8Array		**result,
        REAL8			A,
        REAL8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashD ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashD (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashD" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashDArray ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashDArray (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashDArray" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashSVector ( LALStatus *status, REAL4Vector **result,
		REAL8 A, REAL4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashSVector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL8			A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotSlashSVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashS ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashS (
        LALStatus               *status,
        REAL4Vector          **result,
        REAL4Vector          *A,
        REAL8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashS" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashSVector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, REAL4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashSVector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashSVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashSArray ( LALStatus *status, REAL4Array **result,
		REAL8 A, REAL4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashSArray (
        LALStatus               *status,
        REAL4Array		**result,
        REAL8			A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashS ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashS (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashS" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashSArray ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, REAL4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashSArray (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashSArray" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		REAL8 A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        REAL8			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI2 ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI2 (
        LALStatus               *status,
        INT2Vector          **result,
        INT2Vector          *A,
        REAL8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI2Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI2Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI2Array ( LALStatus *status, INT2Array **result,
		REAL8 A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI2Array (
        LALStatus               *status,
        INT2Array		**result,
        REAL8			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI2 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI2 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI2Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI2Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI2Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI4Vector ( LALStatus *status, INT4Vector **result,
		REAL8 A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI4Vector (
        LALStatus		*status,
        INT4Vector		**result,
        REAL8			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI4 ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI4 (
        LALStatus               *status,
        INT4Vector          **result,
        INT4Vector          *A,
        REAL8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI4Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI4Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI4Array ( LALStatus *status, INT4Array **result,
		REAL8 A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI4Array (
        LALStatus               *status,
        INT4Array		**result,
        REAL8			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI4 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI4 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI4Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI4Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI4Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI8Vector ( LALStatus *status, INT8Vector **result,
		REAL8 A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI8Vector (
        LALStatus		*status,
        INT8Vector		**result,
        REAL8			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DDotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI8 ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, REAL8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI8 (
        LALStatus               *status,
        INT8Vector          **result,
        INT8Vector          *A,
        REAL8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DVectorDotSlashI8Vector ( LALStatus *status, REAL8Vector **result,
		REAL8Vector *A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DVectorDotSlashI8Vector (
        LALStatus		*status,
        REAL8Vector		**result,
        REAL8Vector		*A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "DVectorDotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALDCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DDotSlashI8Array ( LALStatus *status, INT8Array **result,
		REAL8 A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DDotSlashI8Array (
        LALStatus               *status,
        INT8Array		**result,
        REAL8			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI8 ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI8 (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALDCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void DArrayDotSlashI8Array ( LALStatus *status, REAL8Array **result,
		REAL8Array *A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void DArrayDotSlashI8Array (
        LALStatus		*status,
        REAL8Array		**result,
        REAL8Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "DArrayDotSlashI8Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALDCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALDDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashSVector ( LALStatus *status, REAL4Vector **result,
		REAL4 A, REAL4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashSVector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL4			A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotSlashSVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashS ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashS (
        LALStatus               *status,
        REAL4Vector          **result,
        REAL4Vector          *A,
        REAL4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashS" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashSVector ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, REAL4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashSVector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL4Vector		*A,
        REAL4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashSVector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashSArray ( LALStatus *status, REAL4Array **result,
		REAL4 A, REAL4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashSArray (
        LALStatus               *status,
        REAL4Array		**result,
        REAL4			A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashS ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashS (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        REAL4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashS" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashSArray ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, REAL4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashSArray (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        REAL4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashSArray" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((REAL4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((REAL4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALSCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		REAL4 A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        REAL4			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI2 ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI2 (
        LALStatus               *status,
        INT2Vector          **result,
        INT2Vector          *A,
        REAL4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI2Vector ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI2Vector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL4Vector		*A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI2Array ( LALStatus *status, INT2Array **result,
		REAL4 A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI2Array (
        LALStatus               *status,
        INT2Array		**result,
        REAL4			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI2 ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI2 (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI2Array ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI2Array (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI2Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALSCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI4Vector ( LALStatus *status, INT4Vector **result,
		REAL4 A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI4Vector (
        LALStatus		*status,
        INT4Vector		**result,
        REAL4			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI4 ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI4 (
        LALStatus               *status,
        INT4Vector          **result,
        INT4Vector          *A,
        REAL4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI4Vector ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI4Vector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL4Vector		*A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI4Array ( LALStatus *status, INT4Array **result,
		REAL4 A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI4Array (
        LALStatus               *status,
        INT4Array		**result,
        REAL4			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI4 ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI4 (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI4Array ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI4Array (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI4Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALSCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI8Vector ( LALStatus *status, INT8Vector **result,
		REAL4 A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI8Vector (
        LALStatus		*status,
        INT8Vector		**result,
        REAL4			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SDotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI8 ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, REAL4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI8 (
        LALStatus               *status,
        INT8Vector          **result,
        INT8Vector          *A,
        REAL4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SVectorDotSlashI8Vector ( LALStatus *status, REAL4Vector **result,
		REAL4Vector *A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SVectorDotSlashI8Vector (
        LALStatus		*status,
        REAL4Vector		**result,
        REAL4Vector		*A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "SVectorDotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((REAL4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALSCreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SDotSlashI8Array ( LALStatus *status, INT8Array **result,
		REAL4 A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SDotSlashI8Array (
        LALStatus               *status,
        INT8Array		**result,
        REAL4			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI8 ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI8 (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALSCreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void SArrayDotSlashI8Array ( LALStatus *status, REAL4Array **result,
		REAL4Array *A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void SArrayDotSlashI8Array (
        LALStatus		*status,
        REAL4Array		**result,
        REAL4Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "SArrayDotSlashI8Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((REAL4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((REAL4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALSCreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALSDestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2DotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		INT2 A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2DotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        INT2			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2DotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT2Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2VectorDotSlashI2 ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2VectorDotSlashI2 (
        LALStatus               *status,
        INT2Vector          **result,
        INT2Vector          *A,
        INT2                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2VectorDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT2Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2VectorDotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2VectorDotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        INT2Vector		*A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I2VectorDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT2Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2DotSlashI2Array ( LALStatus *status, INT2Array **result,
		INT2 A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2DotSlashI2Array (
        LALStatus               *status,
        INT2Array		**result,
        INT2			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2ArrayDotSlashI2 ( LALStatus *status, INT2Array **result,
		INT2Array *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2ArrayDotSlashI2 (
        LALStatus		*status,
        INT2Array		**result,
        INT2Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I2ArrayDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT2Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT2Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I2ArrayDotSlashI2Array ( LALStatus *status, INT2Array **result,
		INT2Array *A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I2ArrayDotSlashI2Array (
        LALStatus		*status,
        INT2Array		**result,
        INT2Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I2ArrayDotSlashI2Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI2CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4DotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		INT4 A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4DotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        INT4			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4DotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4VectorDotSlashI2 ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4VectorDotSlashI2 (
        LALStatus               *status,
        INT2Vector          **result,
        INT2Vector          *A,
        INT4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4VectorDotSlashI2Vector ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4VectorDotSlashI2Vector (
        LALStatus		*status,
        INT4Vector		**result,
        INT4Vector		*A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4DotSlashI2Array ( LALStatus *status, INT2Array **result,
		INT4 A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4DotSlashI2Array (
        LALStatus               *status,
        INT2Array		**result,
        INT4			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4ArrayDotSlashI2 ( LALStatus *status, INT4Array **result,
		INT4Array *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4ArrayDotSlashI2 (
        LALStatus		*status,
        INT4Array		**result,
        INT4Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4ArrayDotSlashI2Array ( LALStatus *status, INT4Array **result,
		INT4Array *A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4ArrayDotSlashI2Array (
        LALStatus		*status,
        INT4Array		**result,
        INT4Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotSlashI2Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI4CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4DotSlashI4Vector ( LALStatus *status, INT4Vector **result,
		INT4 A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4DotSlashI4Vector (
        LALStatus		*status,
        INT4Vector		**result,
        INT4			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4DotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4VectorDotSlashI4 ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4VectorDotSlashI4 (
        LALStatus               *status,
        INT4Vector          **result,
        INT4Vector          *A,
        INT4                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4VectorDotSlashI4Vector ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4VectorDotSlashI4Vector (
        LALStatus		*status,
        INT4Vector		**result,
        INT4Vector		*A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I4VectorDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT4Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4DotSlashI4Array ( LALStatus *status, INT4Array **result,
		INT4 A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4DotSlashI4Array (
        LALStatus               *status,
        INT4Array		**result,
        INT4			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4ArrayDotSlashI4 ( LALStatus *status, INT4Array **result,
		INT4Array *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4ArrayDotSlashI4 (
        LALStatus		*status,
        INT4Array		**result,
        INT4Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I4ArrayDotSlashI4Array ( LALStatus *status, INT4Array **result,
		INT4Array *A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I4ArrayDotSlashI4Array (
        LALStatus		*status,
        INT4Array		**result,
        INT4Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I4ArrayDotSlashI4Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI4CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}




























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI2Vector ( LALStatus *status, INT2Vector **result,
		INT8 A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI2Vector (
        LALStatus		*status,
        INT2Vector		**result,
        INT8			A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI2 ( LALStatus *status, INT2Vector **result,
		INT2Vector *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI2 (
        LALStatus               *status,
        INT2Vector          **result,
        INT2Vector          *A,
        INT8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI2Vector ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, INT2Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI2Vector (
        LALStatus		*status,
        INT8Vector		**result,
        INT8Vector		*A,
        INT2Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI2Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI2Array ( LALStatus *status, INT2Array **result,
		INT8 A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI2Array (
        LALStatus               *status,
        INT2Array		**result,
        INT8			A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT2Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT2Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI2CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI2DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI2 ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT2 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI2 (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT2			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI2" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI2Array ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT2Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI2Array (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT2Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI2Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT2Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT2Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI8CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI4Vector ( LALStatus *status, INT4Vector **result,
		INT8 A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI4Vector (
        LALStatus		*status,
        INT4Vector		**result,
        INT8			A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI4 ( LALStatus *status, INT4Vector **result,
		INT4Vector *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI4 (
        LALStatus               *status,
        INT4Vector          **result,
        INT4Vector          *A,
        INT8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI4Vector ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, INT4Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI4Vector (
        LALStatus		*status,
        INT8Vector		**result,
        INT8Vector		*A,
        INT4Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI4Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI4Array ( LALStatus *status, INT4Array **result,
		INT8 A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI4Array (
        LALStatus               *status,
        INT4Array		**result,
        INT8			A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT4Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT4Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI4CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI4DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI4 ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT4 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI4 (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT4			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI4Array ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT4Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI4Array (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT4Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI4Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT4Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT4Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI8CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



























/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI8Vector ( LALStatus *status, INT8Vector **result,
		INT8 A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI8Vector (
        LALStatus		*status,
        INT8Vector		**result,
        INT8			A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8DotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(B))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = B->data[iterator] / A;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI8 ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI8 (
        LALStatus               *status,
        INT8Vector          **result,
        INT8Vector          *A,
        INT8                    B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
               (*result)->data[iterator] = A->data[iterator] / B;
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8VectorDotSlashI8Vector ( LALStatus *status, INT8Vector **result,
		INT8Vector *A, INT8Vector *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8VectorDotSlashI8Vector (
        LALStatus		*status,
        INT8Vector		**result,
        INT8Vector		*A,
        INT8Vector		*B
)
{
        /*  Variable Declarations  */
        INT4    iterator;
        UINT4   length;

        INITSTATUS( status, "I8VectorDotSlashI8Vector" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( A->length == B->length, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        length = ((INT8Vector*)(A))->length;

        /*  length must be greater than one  */
        ASSERT ( length > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	LALI8CreateVector( status->statusPtr, result, length);

        for (iterator = 0; iterator < length; iterator++)
        {
                (*result)->data[iterator] = A->data[iterator] / B->data[iterator];
        }

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8DotSlashI8Array ( LALStatus *status, INT8Array **result,
		INT8 A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8DotSlashI8Array (
        LALStatus               *status,
        INT8Array		**result,
        INT8			A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4		iterator, index;
	INT4		row, column;

        INITSTATUS( status, "4" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
	ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

	ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

	LALU4CreateVector( status->statusPtr, &length, ndims);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
	}

	/*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
	        for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
				index = (row * length->data[1]) + column;
				(*result)->data[index] = A / B->data[index];
			}
	        }
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


	LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI8 ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT8 B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI8 (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT8			B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI8" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(A))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(A))->dimLength->data[iterator];
        }

        /*  length must be greater than one  */
        ASSERT ( length->data[0] > 1, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

        LALI8CreateArray( status->statusPtr, result, length);

	if( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = A->data[index] / B;
			}
		}
        }
        else
        {
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
        }


        LALU4DestroyVector( status->statusPtr, &length );

        DETATCHSTATUSPTR( status );
        RETURN (status);
}

/******************************* <lalLaTeX file="MatrixDivideC">
\begin{verbatim}void I8ArrayDotSlashI8Array ( LALStatus *status, INT8Array **result,
		INT8Array *A, INT8Array *B )\end{verbatim}
*************************************************** </lalLaTeX> */

void I8ArrayDotSlashI8Array (
        LALStatus		*status,
        INT8Array		**result,
        INT8Array		*A,
        INT8Array		*B
)
{
        /*  Variable Declarations  */
        UINT4Vector     *length;
        UINT4           ndims;
        UINT4           ndims2;
        INT4            iterator, index;
        INT4            row, column;

        INITSTATUS( status, "I8ArrayDotSlashI8Array" , MATLABMATRIXDIVC);
        ATTATCHSTATUSPTR( status );

        /*  Check input for existence.  */
        /*  Result should not come in Allocated  */
        ASSERT ( result, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);
        ASSERT ( !(*result), status, MATLABMATRIXH_ENNUL, MATLABMATRIXH_MSGENNUL);

        /*  data must be defined  */
        ASSERT ( B, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( B->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims = ((INT8Array*)(B))->dimLength->length;
	length = NULL;

        LALU4CreateVector( status->statusPtr, &length, ndims);

        for ( iterator = 0; iterator < ndims; iterator++)
        {
                length->data[iterator] = ((INT8Array*)(B))->dimLength->data[iterator];
        }

        /*  data must be defined  */
        ASSERT ( A, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ASSERT ( A->dimLength, status, MATLABMATRIXH_ENULL, MATLABMATRIXH_MSGENULL);

        ndims2 = ((INT8Array*)(A))->dimLength->length;

	ASSERT ( ndims == ndims2, status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);

	for ( iterator = 0; iterator < ndims; iterator++)
	{
		ASSERT ( length->data[iterator] == ((INT8Array*)(A))->dimLength->data[iterator], status, MATLABMATRIXH_ELNTH, MATLABMATRIXH_MSGELNTH);
	}

        LALI8CreateArray( status->statusPtr, result, length);

	if ( ndims == 2 )
	{
		for( row = 0; row < length->data[0]; row++)
		{
			for( column = 0; column < length->data[1]; column++)
			{
                                index = (row * length->data[1]) + column;
				(*result)->data[index] = (A->data[index]) / (B->data[index]);
			}
		}
	}
	else
	{
		LALI8DestroyArray( status->statusPtr, result);
		(*result) = NULL;
	}

        LALU4DestroyVector( status->statusPtr, &length );
        DETATCHSTATUSPTR( status );
        RETURN (status);
}



