/* -*- mode: c; c-basic-offset: 2; -*- */
/******** <lalVerbatim file="ExtTrigBuildOutputCV"> ********
Author: Rahkola, R
$Id: ExtTrigBuildOutput.c,v 1.8 2002/04/23 00:57:01 rrahkola Exp $
********* </lalVerbatim> ********/

/* standard C functions */
#include <math.h>
#include <stdio.h>
#include <string.h>

/* standard LAL functions*/
#include <lal/LALStdlib.h>
#include <lal/AVFactories.h>

/* LAL MPI interface */
#include <lal/Comm.h>

/* Associated headers */
#include <ExtTrig.h>
#include <ExtTrigApplySearch.h>

#ifdef __cplusplus
extern "C" {
#endif

NRCSID( EXTTRIGBUILDOUTPUTC, "$Id: ExtTrigBuildOutput.c,v 1.8 2002/04/23 00:57:01 rrahkola Exp $" );

/********************** local static function definitions ********************/

/*
 * Function BuildOutput
 *
 * Create a linked list containing the database entries and put it in
 * the search output structure
 */
void
ExtTrigBuildOutput(
		   LALStatus             *const status,
		   LALSearchOutput       *const output,
		   const ETSearchParams  *const params )
{
  /*
   * :TODO: Eventually we need a method of writing statistics for each segment
   * :TODO:to the database. Idea is to fill MULTI_BURST table with the
   * :TODO:following fields correspondences:
   * :TODO: creator_db & process_id:  (auto-filled)
   * :TODO: filter_id      = "GRB (on/off)-src"
   * :TODO: ifos           = "H1 H2" | "H1 L1" | "H2 L1" | ... 
   * :TODO: start_time     = gpsSeconds of GRB trigger
   * :TODO: start_time_ns  = gpsNSeconds of GRB trigger
   * :TODO: duration       = inputWindow
   * :TODO: central_freq   = xCorrDelay (- if on source, + if off source)
   * :TODO: bandwidth      = xCorrLag (+ if chan1 first, - if chan2 first)
   * :TODO: amplitude      = xCorrValue
   * :TODO: snr            = <blank>
   * :TODO: confidence     = % bad data quality
   * :TODO: ligo_axis_ra   = source_ra
   * :TODO: ligo_axis_dec  = source_dec
   * :TODO: ligo_angle     = variance1
   * :TODO: ligo_angle_sig = variance2
   * :TODO: event_id       = "v0.1,j001,1" -> ver 0.1, jobID 1, input mask=1
   *
   * :TODO:To implement Student's t-statistic, only need mean's and var's.
   */
  /*
   * The program name which appears in the PROGRAM field of
   * the SUMM_STATISTICS table (not sure if I need this yet)
   */
  /* const CHAR             *const PROGRAM = "ExtTrig"; */
  dataBase               *prev          = 0; /* pointer to previous db link */
  dataBase               *dbColumn      = 0; /* pointer to current db link */
  UINT4                   dbLength      = params->result->xCorrValue->length;
  outPut                 *outputArray   = 0; /* searchOutput results  */
  UINT4                   i, slength;  /* iterator(s), string length */
  /* strings to be placed in the database; some will vary for on/off-source */
  /* the lengths are determined by the multi_burst table definition         */
  CHAR *filter_on, *filter_off, *ifos, *event_on, *event_off;
  CHAR tmp[4]; /* temporary placeholder for event_* strings */
  
  INITSTATUS( status, "BuildOutput", EXTTRIGBUILDOUTPUTC );
  ATTATCHSTATUSPTR( status );

#ifdef DEBUG_EXTTRIG
  fprintf(stdout, "exttrig:BuildOutput\n");
  fflush(stdout);
#endif

  /*
   *
   * setup output strings: filter_on/off, ifos, & event_on/off
   * :NOTE: filter_id and event_id will 
   *
   */
  /* first the event_id strings */
  event_on   = (CHAR *) LALCalloc( 13, sizeof(CHAR) );
  event_off  = (CHAR *) LALCalloc( 13, sizeof(CHAR) );
  sprintf( event_on,  "GRB  on-src" );
  sprintf( event_off, "GRB off-src" );
  /* next the ifos string */
  ifos       = (CHAR *) LALCalloc( 12, sizeof(CHAR) );
  strncat( ifos, params->chan1, 2 );
  strcat ( ifos, " " );
  strncat( ifos, params->chan2, 2 );
  /* finally the filter_id strings */
  filter_on  = (CHAR *) LALCalloc( 13, sizeof(CHAR) );
  filter_off = (CHAR *) LALCalloc( 13, sizeof(CHAR) );
  sprintf( filter_on,  EXTTRIG_VER );
  sprintf( filter_off, EXTTRIG_VER );
  /* :TODO: It would be nice to somehow put in the job number in the event_id*/
  strcat ( filter_on,  ",j000" );
  strcat ( filter_off, ",j000" );
  sprintf( tmp, ",%u", params->initParams->initMask      ); /* off-source */
  strcat ( filter_off, tmp );
  sprintf( tmp, ",%u", (params->initParams->initMask +1) ); /* on-source  */
  strcat ( filter_on,  tmp );


  /*
   *
   * create memory for the outPut array, with dbLength results
   *
   */
  outputArray = output->result = (outPut *) 
    LALMalloc( dbLength * sizeof(outPut) );
  if ( !outputArray ) { 
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC );
  }


  /*
   *
   * setup the final values for the LALSearchOutput elements
   *
   */
  output->numOutput     = 1;
  output->fracRemaining = 0.0;
  output->notFinished   = 0;


  /*
   * initialize the output array : atomic datatypes
   *
   */
  (*outputArray).indexNumber  = 0;
  (*outputArray).search       = burst;
  (*outputArray).significant  = 1;
  (*outputArray).states       = NULL;
  (*outputArray).results      = NULL;
  (*outputArray).optional     = NULL;


  /*
   * initialize the output array : database linked list (by columns)
   * :NOTE: Since the exttrig produces multiple statistics for each GRB trigger
   * :NOTE:we can make use of the "numberRows" feature of the dataBase linked
   * :NOTE:list.  Thus in what follows, we'll always be allocating "dbLength"
   * :NOTE:number of entries, and filling them in one at a time.
   * :NOTE: Alternatively, we could have set output->numOutput to the number of
   * :NOTE:rows we want to enter and always keep "numberRows"=1.  I feel this
   * :NOTE:method, although it involves more for loops, requires less time in
   * :NOTE:memory allocation, and is more representative of the fact that all
   * :NOTE:rows are related to the same GRB event.
   *
   */
  dbColumn = 
    outputArray->results = (dataBase *) LALCalloc( 1, sizeof(dataBase) ); 
  if ( !dbColumn ) {
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC ); 
  } 
  dbColumn->previous = NULL;

  /*
   * 2nd column: filter_id (char[13]) = e.g. "v0.1,j000,2" version,job,mask
   * :NOTE: creator_db and process_id columns are auto-filled
   */
/*  :NOTE: filter_id and event_id columns are also auto-filled, or something
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "filter_id" );
  dbColumn->type          = char_s_ptr;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = (UINT4 *) LALMalloc( dbLength * sizeof(UINT4) );
  slength = strlen(filter_off);
  dbColumn->rows.chars    =
    (CHAR *) LALCalloc( dbLength * slength, sizeof(CHAR) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rowDimensions[i] = slength;
    if ( !i ) strncpy( dbColumn->rows.chars + i * slength, 
		       filter_on,  slength * sizeof(CHAR) );
    else      strncpy( dbColumn->rows.chars + i * slength, 
		       filter_off, slength * sizeof(CHAR) );
  }
*/
  prev = dbColumn; /* move to next column */
/*
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );
*/
  /*
   * 3rd column: ifos (non-null char[12]) = "H1 H2" | "H1 L1" | "H2 L1" etc.
   */
/*
  dbColumn->previous      = prev;
*/
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "ifos" );
  dbColumn->type          = char_s_ptr;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = (UINT4 *) LALMalloc( dbLength * sizeof(UINT4) );
  slength = strlen(ifos);
  dbColumn->rows.chars    =
    (CHAR *) LALCalloc( dbLength * slength, sizeof(CHAR) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rowDimensions[i] = slength;
    strncpy( dbColumn->rows.chars + i*slength, ifos, slength * sizeof(CHAR) );
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 4th column: start_time (non-null INT4) = GRB start time
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "start_time" );
  dbColumn->type          = int_4s;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.int4s    = (INT4 *) LALCalloc( dbLength, sizeof(INT4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.int4s[i]    = params->initParams->grbStart.gpsSeconds;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 5th column: start_time_ns (non-null INT4) = GRB start time (ns)
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "start_time_ns" );
  dbColumn->type          = int_4s;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.int4s    = (INT4 *) LALCalloc( dbLength, sizeof(INT4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.int4s[i]    = params->initParams->grbStart.gpsNanoSeconds;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 6th column: duration (non-null REAL4) = segment length (seconds)
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "duration" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i] = 
      (REAL4) params->initParams->segLength / (REAL4) GW_SAMPLE;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 7th column: central_freq (REAL4) = delay from GRB start to segment start
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "central_freq" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i]    = params->result->xCorrDelay->data[i];
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 8th column: bandwidth (REAL4) = expected time lag for GW chan1 -> chan2
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "bandwidth" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i]    = params->result->xCorrLag->data[i];
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 9th column: amplitude (non-null REAL4) = cross-correlation statistic
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "amplitude" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i]    = params->result->xCorrValue->data[i];
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 10th column: snr (REAL4) = blank
   */
  /*
   * 11th column: confidence (REAL4) = % of bad data used in segment
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "confidence" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    if( !i ) dbColumn->rows.real4[i] = params->result->badSeconds;
    /* :NOTE: This should change if we start allowing off-src segments to cross
     * :NOTE:up to some threshold of bad data points.
     */
    else     dbColumn->rows.real4[i] = 0;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 12th column: ligo_axis_ra (REAL4) = GRB source right ascension angle
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "ligo_axis_ra" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i] = (REAL4) params->initParams->sourceDir.latitude;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 13th column: ligo_axis_dec (REAL4) = GRB source declination angle
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "ligo_axis_dec" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i] = (REAL4) params->initParams->sourceDir.longitude;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 14th column: ligo_angle (REAL4) = variance, channel 1
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "ligo_angle" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i]    = params->result->variance1;
  }
  prev = dbColumn; /* move to next column */
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );

  /*
   * 15th column: ligo_angle_sig (REAL4) = variance, channel 2
   */
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "ligo_angle_sig" );
  dbColumn->type          = real_4;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = NULL;
  dbColumn->rows.real4    = (REAL4 *) LALCalloc( dbLength, sizeof(REAL4) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rows.real4[i]    = params->result->variance2;
  }
/*
  prev = dbColumn; *//* move to next column *//*
  dbColumn = prev->next = (dataBase *) LALCalloc( 1, sizeof(dataBase) );
*/
  /*
   * 16th column: event_id (non-null CHAR[13]) = "GRB (on/off)-src"
   */
/* :NOTE: filter_id and event_id are auto-filled
  dbColumn->previous      = prev;
  sprintf( dbColumn->tableName,  "multi_burst" );
  sprintf( dbColumn->columnName, "event_id" );
  dbColumn->type          = char_s_ptr;
  dbColumn->numberRows    = dbLength;
  dbColumn->rowDimensions = (UINT4 *) LALMalloc( dbLength * sizeof(UINT4) );
  slength = strlen(event_off);
  dbColumn->rows.chars    =
    (CHAR *) LALCalloc( dbLength * slength, sizeof(CHAR) );
  for ( i = 0; i < dbLength; i++ ) {
    dbColumn->rowDimensions[i] = slength;
    if ( !i ) strncpy( dbColumn->rows.chars + i * slength, 
		       event_on,   slength * sizeof(CHAR) );
    else      strncpy( dbColumn->rows.chars + i * slength, 
		       event_off,  slength * sizeof(CHAR) );
  }
*/
  dbColumn->next = NULL;
      
  /*
   * Free temporary allocated memory
   */
  LALFree( filter_off );
  LALFree( filter_on );
  LALFree( ifos );
  LALFree( event_off );
  LALFree( event_on );

  /* normal exit */
  DETATCHSTATUSPTR( status );
  RETURN( status );
}


/*
 * Function BuildOutput
 *
 * Create a linked list containing the database entries and put it in
 * the search output structure
 */
void
ExtTrigBuildILWD(
		 LALStatus               *const status,
		 LALSearchOutput         *const output,
		 const ETSearchParams    *const params )
{
  const CHAR             *const PROGRAM = "ExtTrig";
  multiDimData           *mddEntry      = 0;
  UINT4                   mddLength     = params->result->xCorrValue->length;
  outPut                 *outputArray   = 0;
  
  INITSTATUS( status, "BuildILWD", EXTTRIGBUILDOUTPUTC );
  ATTATCHSTATUSPTR( status );

#ifdef DEBUG_EXTTRIG
  fprintf(stdout, "exttrig:BuildILWD\n");
  fflush(stdout);
#endif

  /*
   *
   * create memory for the outPut array
   *
   */
  outputArray = output->result = (outPut *) LALMalloc( sizeof(outPut) );
  if ( !outputArray ) { 
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC );
  }


  /*
   *
   * setup the final values for the LALSearchOutput elements
   *
   */
  output->numOutput     = 1;
  output->fracRemaining = 0.0;
  output->notFinished   = 0;


  /*
   *
   * initialize the output array : atomic datatypes & memory allocation
   *
   */
  (*outputArray).indexNumber  = 0;
  (*outputArray).search       = burst;
  (*outputArray).significant  = 1;
  (*outputArray).states       = NULL;
  (*outputArray).results      = NULL;
  (*outputArray).optional     = NULL;

  mddEntry = outputArray->optional =
    (multiDimData *) LALCalloc( 1, sizeof(multiDimData) );
  if ( !mddEntry ) {
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC );
  }


  /*
   * initialize the output array : multiDimData structure
   *
   */
  /* CHAR        name[maxMultiDimName] */
  sprintf( mddEntry->name, "ExtTrig result" );
  /* CHAR        units[maxMultiDimUnits] */
  sprintf( mddEntry->units, "dimensionless" );
  /* domain      space */
  mddEntry->space      = timeD;
  /* datatype    type */
  mddEntry->type       = real_4;
  /* interval    range :: complex datatype */
  mddEntry->range.dTime.numberSamples =  /* UINT8 numberSamples */
    (UINT8) params->initParams->segLength;
  mddEntry->range.dTime.startSec =  /* UINT4 startsec */
    (UINT4) params->initParams->grbStart.gpsSeconds;
  mddEntry->range.dTime.startNan =  /* UINT4 startNan */
    (UINT4) params->initParams->grbStart.gpsNanoSeconds;
  mddEntry->range.dTime.stopSec =  /* UINT4 stopSec */
    (UINT4) params->initParams->onTimeShift;
  mddEntry->range.dTime.stopNan = 0; /* UINT4 stopNan */
  mddEntry->range.dTime.timeStepSize =  /* REAL8 timeStepSize -- non-null */
    (REAL8) params->initParams->offTimeShiftLow;
  mddEntry->range.dTime.baseFreq =  /* REAL8 baseFreq */
    (REAL8) params->result->badSeconds;
  mddEntry->range.dTime.phase =  /* REAL8 phase */
    (REAL8) params->result->xCorrLag->data[0];
  /* UINT4       numberDimensions */
  mddEntry->numberDimensions = 2; /* correspond to ccStatistic & offset */
  /* UINT4*      dimensions */
  mddEntry->dimensions = (UINT4 *) LALMalloc( 2 * sizeof(UINT4) );
  if ( !(mddEntry->dimensions) ) {
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC );
  }
  /* :TODO: add variances as data */
  mddEntry->dimensions[0] = mddEntry->dimensions[1] = mddLength;
  /* dcHistory*  history */
  mddEntry->history    = NULL;
  /* dataPointer data */
  /* :TODO: add 2 to the size to include variances */
  mddEntry->data.real4 = (REAL4 *) 
    LALCalloc ( 2 * mddLength, sizeof(REAL4) );
  if ( !(mddEntry->data.real4) ) {
    ABORT( status, APPLYSEARCHH_EALOC, APPLYSEARCHH_MSGEALOC );
  }

  /*
   * Copy the data to multiDimData structure
   *
   */
  memcpy( mddEntry->data.real4, params->result->xCorrValue->data, 
	  mddLength * sizeof(REAL4) );
  memcpy( &(mddEntry->data.real4[mddLength]), params->result->xCorrDelay->data,
	  mddLength * sizeof(REAL4) );

  /* normal exit */
  DETATCHSTATUSPTR( status );
  RETURN( status );
}

#ifdef __cplusplus
}
#endif
