/********************************** <lalVerbatim file="TFCApplySearchCV">
Author: Julien Sylvestre
$Id: ApplySearch.c,v 1.19 2002/08/13 19:47:32 julien Exp $
**************************************************** </lalVerbatim> */

#include <lal/LALStdlib.h>
#include <lal/LALDatatypes.h>
#include <lal/TFClusters.h>
#include <lal/Comm.h>
#include <InitSearch.h>
#include <ApplySearch.h>

#include <pthread.h>
#include <unistd.h>
#include <BuildDB.h>

NRCSID( APPLYSEARCHC, "power $Id: ApplySearch.c,v 1.19 2002/08/13 19:47:32 julien Exp $");

void
LALApplySearch(
    LALStatus             *status,
    LALSearchOutput       *output,
    LALSearchInput        *input,
    LALApplySearchParams  *applyParams
    )
{
  static BOOLEAN firsttime = 1;

  static UINT4 TSeg = 0, 
    olap = 0,
    numSlaves = 0, 
    numSlaves0 = 0,
    totalSegments = 0, 
    currentSegment = 0;

  static BOOLEAN mainlistDef = 0;

  static CList *mainlist = NULL;

  static REAL4 frRem = 1.0;

  UINT4 i,j;
  INT4 myRank;
  TFCSearchParams *params = (TFCSearchParams*)applyParams->searchParams;
  InitExchParams           initExchParams;

  CList *tmplist;

  INITSTATUS (status, "LALApplySearch", APPLYSEARCHC);
  ATTATCHSTATUSPTR (status);

 
  /*
   *
   * determine rank and check that we're running on a physical slave
   *
   */

  
  MPI_Comm_rank( *(applyParams->mpiParams->comm), &myRank );

  /* check that the master is running on node rank zero */
  if ( params->searchMaster && myRank != 0 )
  {
    ABORT( status, APPLYSEARCHH_ERANK, APPLYSEARCHH_MSGERANK );
  }

  /* and that the slave is not running on node rank zero */
  if ( !params->searchMaster && myRank == 0 )
  {
    ABORT( status, APPLYSEARCHH_ERANK, APPLYSEARCHH_MSGERANK );
  }
 
  initExchParams.mpiComm   = *(applyParams->mpiParams->comm);
  initExchParams.myProcNum = myRank;



  if(params->searchMaster && firsttime)  {

    /* only do this the first time the master is called */

    /* get the number of search slaves */
    numSlaves = 0;
    MPI_Comm_size( *(applyParams->mpiParams->comm), &numSlaves );
    numSlaves--;
    numSlaves0 = numSlaves;

    totalSegments = (UINT4)floor((REAL4)(params->NData - params->olap) / (REAL4)(params->Ttotal - params->olap));

    if(totalSegments * (params->Ttotal - params->olap) + params->olap != params->NData) {
      ABORT(status, APPLYSEARCHH_ENDAT, APPLYSEARCHH_MSGENDAT);
    }


    TSeg = params->Ttotal;
    olap = params->olap;

    currentSegment = 0;

    mainlist = NULL;
    mainlistDef = 0;

    firsttime = 0;
  }


  
  /* 
   *
   * the main engine starts here.  On the master 
   *
   */

  if(params->searchMaster) {

    if ( numSlaves > 0 )
    {
      ExchParams *thisExch = NULL;

      /* wait for a message */
      LALInitializeExchange (status->statusPtr, &thisExch, NULL, &initExchParams);
      CHECKSTATUSPTR (status);
      
      /* case the exchange type */
      switch (thisExch->exchObjectType)
      {
      case ExchDataList:

	if ( currentSegment < totalSegments )
          {
            /* tell the slave the segment number */
            LALExchangeUINT4 (status->statusPtr, &currentSegment, thisExch);
            CHECKSTATUSPTR (status);

            /* tell the slave the segment size */
            LALExchangeUINT4 (status->statusPtr, &TSeg, thisExch);
            CHECKSTATUSPTR (status);

            /* tell the slave the overlap */
            LALExchangeUINT4 (status->statusPtr, &olap, thisExch);
            CHECKSTATUSPTR (status);
	    
            /* increment to the next segment number to be analyzed */
            currentSegment++;
          }

          /*
           *
           * otherwise tell the slave there is no more data to analyze 
           *
           */
          
          else
          {
            UINT4       tmpDutyCycle;

            
            tmpDutyCycle = -1;
            LALExchangeUINT4 (status->statusPtr, &tmpDutyCycle, thisExch);
            CHECKSTATUSPTR (status);
          }
	break;


      case ExchEPEvent:

	tmplist = NULL;

	LALExchangeTFCList(status->statusPtr, &tmplist, &(params->tseries->epoch), thisExch);
	CHECKSTATUSPTR (status);

	if(!mainlistDef)
	  {
	    mainlist = tmplist;
	    mainlistDef=1;
	  }
	else {

	  LALMergeClusterLists(status->statusPtr, mainlist, mainlist, tmplist);
	  CHECKSTATUSPTR (status);

	  LALFreeCList(status->statusPtr, tmplist);
	  CHECKSTATUSPTR (status);
	  
	  LALFree(tmplist);
	}
	
	frRem -= 1.0 / (REAL4)(1+totalSegments);

	break;


      case ExchFinished:
	
	--numSlaves;
	break;

      case ExchBeacon:
	break;

      default: 
	ABORT( status, APPLYSEARCHH_EUEXT, APPLYSEARCHH_MSGEUEXT );
      }

      /* finish the exchange */
      LALFinalizeExchange (status->statusPtr, &thisExch);
      CHECKSTATUSPTR (status);

      /* 
       *
       * set fraction remaining
       *
       */

      output->numOutput = 0;
      output->result = NULL;
      output->fracRemaining = frRem;
      output->notFinished = 1;
    }
    else {
      BuildTFCOutput(status->statusPtr,
		     output,
		     mainlist,
		     params->tseries->epoch.gpsSeconds,
		     params->tseries->epoch.gpsNanoSeconds,
		     params->name,
		     params->table,
		     params->resp,
		     params->spec,
		     params->WriteBlobs,
		     (REAL8)(params->NData) / (REAL8)(params->fs),
		     numSlaves0);

      CHECKSTATUSPTR (status);
      
      LALFreeCList(status->statusPtr, mainlist);
      CHECKSTATUSPTR (status);

      LALFree(mainlist);

      output->fracRemaining = 0;
      output->notFinished   = 0;
    }
  }
  else
  {
    CList clist, list;
    CList *listptr = &list;
    Spectrogram spower;

    UINT4 segid;

    ExchParams             *thisExch = NULL;
    ExchParams              exchDutyCycle;
    ExchParams              exchFinished;
    ExchParams              exchEvents;



    /* exchange finished message */
    exchFinished.exchObjectType  = ExchFinished;
    exchFinished.send            = 0;  /* master sends */
    exchFinished.numObjects      = 0;
    exchFinished.partnerProcNum  = 0;  /* master */

    /* exchange duty cycle information */
    exchDutyCycle.exchObjectType = ExchDataList;
    exchDutyCycle.send           = 0; /* master sends */
    exchDutyCycle.numObjects     = 1; /* i send */
    exchDutyCycle.partnerProcNum = 0; /* master */

    /* exchange event information */
    exchEvents.exchObjectType = ExchEPEvent;
    exchEvents.send           = 1; /* i send */
    exchEvents.numObjects     = 1; /* i send */
    exchEvents.partnerProcNum = 0; /* master */

    LALInitializeExchange (status->statusPtr, &thisExch, 
			   &exchDutyCycle, &initExchParams);
    CHECKSTATUSPTR (status);

    LALExchangeUINT4 (status->statusPtr, &segid, thisExch);
    CHECKSTATUSPTR (status);

    if(segid == -1) {
     
      LALFinalizeExchange (status->statusPtr, &thisExch);
      CHECKSTATUSPTR (status);

      LALInitializeExchange (status->statusPtr, &thisExch, 
          &exchFinished, &initExchParams);
      CHECKSTATUSPTR (status);

      LALFinalizeExchange (status->statusPtr, &thisExch);
      CHECKSTATUSPTR (status);

      /* make sure to tell the wrapperAPI that we're done */
      output->fracRemaining = 0;
      output->notFinished   = 0;

      DETATCHSTATUSPTR (status);
      RETURN (status);

    }
    else {
      UINT4 segsiz, delT, overlap, timeShift;

      TArg targ;
      static void *beacon(void *s);
      pthread_t sleeper;

      LALExchangeUINT4 (status->statusPtr, &segsiz, thisExch);
      CHECKSTATUSPTR (status);

      LALExchangeUINT4 (status->statusPtr, &overlap, thisExch);
      CHECKSTATUSPTR (status);

      LALFinalizeExchange (status->statusPtr, &thisExch);
      CHECKSTATUSPTR (status);

      targ.on = 1;
      targ.init = &initExchParams;
      if(pthread_create(&sleeper, NULL, beacon, &targ)) {
	ABORT( status, APPLYSEARCHH_ETHREAD, APPLYSEARCHH_MSGETHREAD );
      }
      if(!(params->tseries->data)) {

	LALCreateVector(status->statusPtr, &(params->tseries->data), segsiz);
	CHECKSTATUSPTR (status);

      }

      delT = segid * (segsiz - overlap);
      timeShift = (UINT4)floor((REAL4)(segid * (segsiz - overlap)) * params->tseries->deltaT / params->T);

      memcpy(params->tseries->data->data, params->dmro + delT, segsiz * sizeof(REAL4));

      LALPlainSpectrogram(status->statusPtr, params->tspec, params->tseries, params->T);
      CHECKSTATUSPTR (status);

      spower.power = NULL;
      spower.params = NULL;
      LALComputeSpectrogram(status->statusPtr, &spower, params->tspec, params->tseries);
      CHECKSTATUSPTR (status);

      LALInitCList(status->statusPtr, &clist, params->tspec); 
      CHECKSTATUSPTR (status);

      LALGetClusters(status->statusPtr, &clist, &spower, params->dir);
      CHECKSTATUSPTR (status);

      LALFreeSpecgram(status->statusPtr, &spower);
      CHECKSTATUSPTR (status);

      LALInitCList(status->statusPtr, &list, params->tspec); 
      CHECKSTATUSPTR (status);

      if(clist.nclusters > 0) { /* this should be fixed in lal */
	LALClustersPowerThreshold(status->statusPtr, &list, &clist, params->dir);
	CHECKSTATUSPTR (status);
      }

      LALFreeCList(status->statusPtr, &clist);
      CHECKSTATUSPTR (status);

      /* shift time to match other nodes */
      for(i=0; i<list.nclusters; i++) 
	for(j=0; j<list.sizes[i]; j++)
	  list.t[i][j] += timeShift;

      targ.on = 0;
      if(pthread_join(sleeper,NULL)) {
	ABORT( status, APPLYSEARCHH_ETHREAD, APPLYSEARCHH_MSGETHREAD );
      }
      thisExch = NULL;
      LALInitializeExchange (status->statusPtr, &thisExch, 
			     &exchEvents, &initExchParams);
      CHECKSTATUSPTR (status);

      LALExchangeTFCList(status->statusPtr, &listptr, &(params->tseries->epoch), thisExch);
      CHECKSTATUSPTR (status);
	
    
      LALFinalizeExchange (status->statusPtr, &thisExch);
      CHECKSTATUSPTR (status);
      

      
      LALFreeCList(status->statusPtr, &list);
      CHECKSTATUSPTR (status);
      

      output->numOutput     = 0;
      output->result        = NULL;
      output->fracRemaining = 0;
      output->notFinished   = 1;
    }
  }


  DETATCHSTATUSPTR (status);
  RETURN (status);
}


static void *beacon(void *s) {
  /* send beacon signal every minute */
  int sl;
  static LALStatus status;
  ExchParams             *thisExch = NULL;
  ExchParams              exchBeacon;
  TArg *targ = (TArg *)s;
  InitExchParams *initExchParams = targ->init;

  /* exchange finished message */
  exchBeacon.exchObjectType  = ExchBeacon;
  exchBeacon.send            = 0;  /* master sends */
  exchBeacon.numObjects      = 0;
  exchBeacon.partnerProcNum  = 0;  /* master */

  while(targ->on) {
    
    for(sl=0;sl<30;sl++) 
      {
	if(!(targ->on)) break;
	sleep(1);
      }

    if(!(targ->on)) break;

    LALInitializeExchange (&status, &thisExch, 
			   &exchBeacon, initExchParams);
    /*
    CHECKSTATUSPTR (status);
    */
    LALFinalizeExchange (&status, &thisExch);
    /*
    CHECKSTATUSPTR (status);
    */
  }

  return NULL;
}


static void
LALExchangeTFCList (
		    LALStatus *status,
		    CList **clist,
		    LIGOTimeGPS *epch, /* have to exchange that because master doesn't run ConditionData.c */
		    ExchParams       *exchParams
		    )
{
  UINT4 i;
  CHARVector box;

  INITSTATUS (status, "LALExchangeTFCList", APPLYSEARCHC);
  ATTATCHSTATUSPTR (status);

  ASSERT(exchParams, status, APPLYSEARCHH_ENULL, APPLYSEARCHH_MSGENULL);
  
  if (exchParams->send)  /* I am sending */
    {
      INT4 dest = exchParams->partnerProcNum;

      ASSERT(*clist, status, APPLYSEARCHH_ENULL, APPLYSEARCHH_MSGENULL);

      box.length = sizeof(TFPlaneParams);
      box.data = (CHAR *)(*clist)->params;
      LALMPISendCHARVector (status->statusPtr, &box, dest, exchParams->mpiComm);
      CHECKSTATUSPTR (status);

      box.length = 4;
      box.data = (CHAR *)(&((*clist)->nclusters));
      LALMPISendCHARVector(status->statusPtr, &box, dest, exchParams->mpiComm);
      CHECKSTATUSPTR (status);

      if((*clist)->nclusters) {

	box.length = (*clist)->nclusters * sizeof(UINT4);
	box.data = (CHAR *)((*clist)->sizes);
	LALMPISendCHARVector(status->statusPtr, &box, dest, exchParams->mpiComm);
	CHECKSTATUSPTR (status);


	for(i=0;i<(*clist)->nclusters;i++) {
	  box.length = (*clist)->sizes[i] * sizeof(UINT4);
	  box.data = (CHAR *)(*clist)->t[i];

	  LALMPISendCHARVector (status->statusPtr, &box, dest, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);

	  box.data = (CHAR *)(*clist)->f[i];
	  LALMPISendCHARVector (status->statusPtr, &box, dest, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);
	 
	  box.length = (*clist)->sizes[i] * sizeof(REAL8);
	  box.data = (CHAR *)(*clist)->P[i];
	  LALMPISendCHARVector (status->statusPtr, &box, dest, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);
	}
      }

      box.length = 4;
      box.data = (CHAR *)(&(epch->gpsSeconds));
      LALMPISendCHARVector(status->statusPtr, &box, dest, exchParams->mpiComm);
      CHECKSTATUSPTR (status);

      box.length = 4;
      box.data = (CHAR *)(&(epch->gpsNanoSeconds));
      LALMPISendCHARVector(status->statusPtr, &box, dest, exchParams->mpiComm);
      CHECKSTATUSPTR (status);

    }
  else /* I am receiving */
    {
      INT4 source = exchParams->partnerProcNum;

      (*clist) = (CList *)LALMalloc(sizeof(CList));
      if(!clist) {
	ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
      }

      box.length = sizeof(TFPlaneParams);
      box.data = LALMalloc(sizeof(TFPlaneParams));
      if(!box.data) {
	ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
      }
      LALMPIRecvCHARVector (status->statusPtr, &box, source, exchParams->mpiComm);
      CHECKSTATUSPTR (status);
      LALInitCList(status->statusPtr, (*clist), (TFPlaneParams *)(box.data));
      CHECKSTATUSPTR (status);
      LALFree(box.data);

      
      box.length=sizeof(UINT4);
      box.data=LALMalloc(sizeof(UINT4));
      if(!box.data) {
	ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
      }
      LALMPIRecvCHARVector(status->statusPtr, &box, source, exchParams->mpiComm);
      CHECKSTATUSPTR (status);
      (*clist)->nclusters = *((UINT4 *)(box.data));
      LALFree(box.data);


      if((*clist)->nclusters) {
	(*clist)->sizes = (UINT4 *)LALMalloc((*clist)->nclusters * sizeof(UINT4));
	(*clist)->t = (UINT4 **)LALMalloc((*clist)->nclusters * sizeof(UINT4 *));
	(*clist)->f = (UINT4 **)LALMalloc((*clist)->nclusters * sizeof(UINT4 *));
	(*clist)->P = (REAL8 **)LALMalloc((*clist)->nclusters * sizeof(REAL8 *));
      
	box.length=(*clist)->nclusters * sizeof(UINT4);
	box.data = (CHAR *)((*clist)->sizes);
	LALMPIRecvCHARVector(status->statusPtr, &box, source, exchParams->mpiComm);
	CHECKSTATUSPTR (status);


	for(i=0;i<(*clist)->nclusters;i++) {

	  (*clist)->t[i] = (UINT4 *)LALMalloc((*clist)->sizes[i] * sizeof(UINT4));
	  if(!(*clist)->t[i]) {
	    ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
	  }

	  (*clist)->f[i] = (UINT4 *)LALMalloc((*clist)->sizes[i] * sizeof(UINT4));
	  if(!(*clist)->f[i]) {
	    ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
	  }

	  (*clist)->P[i] = (REAL8 *)LALMalloc((*clist)->sizes[i] * sizeof(REAL8));
	  if(!(*clist)->P[i]) {
	    ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
	  }


	  box.length = (*clist)->sizes[i] * sizeof(UINT4);
	  box.data = (CHAR *)((*clist)->t[i]);
	  LALMPIRecvCHARVector (status->statusPtr, &box, source, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);

	  box.data = (CHAR *)((*clist)->f[i]);
	  LALMPIRecvCHARVector (status->statusPtr, &box, source, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);

	  box.length = (*clist)->sizes[i] * sizeof(REAL8);
	  box.data = (CHAR *)((*clist)->P[i]);
	  LALMPIRecvCHARVector (status->statusPtr, &box, source, exchParams->mpiComm);
	  CHECKSTATUSPTR (status);
	}
      }

      box.length=sizeof(UINT4);
      box.data=LALMalloc(sizeof(UINT4));
      if(!box.data) {
	ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
      }
      LALMPIRecvCHARVector(status->statusPtr, &box, source, exchParams->mpiComm);
      CHECKSTATUSPTR (status);
      epch->gpsSeconds = *((UINT4 *)(box.data));
      LALFree(box.data);


      box.length=sizeof(UINT4);
      box.data=LALMalloc(sizeof(UINT4));
      if(!box.data) {
	ABORT (status, INITSEARCHH_EALOC, INITSEARCHH_MSGEALOC);
      }
      LALMPIRecvCHARVector(status->statusPtr, &box, source, exchParams->mpiComm);
      CHECKSTATUSPTR (status);
      epch->gpsNanoSeconds = *((UINT4 *)(box.data));
      LALFree(box.data);


    }

  DETATCHSTATUSPTR (status);
  RETURN (status);
}


static void BuildTFCOutput(LALStatus *status,
			   LALSearchOutput *output,
			   CList *clist,
			   UINT4 t0Sec,
			   UINT4 t0NanoSec,
			   char *name,
			   DbTable table,
			   REAL4 *resp,
			   REAL4 *spec,
			   BOOLEAN TFC_BLOB__,
			   REAL8 tDuration,
			   UINT4 numSlaves)
{

#ifdef linux
  void endian_swap(char * pdata, int dsize, int nelements);
#endif



  outPut               *outputArray;
  dataBase             *prev;
  dataBase             *dbEntry;
  UINT4 i, j, mint, maxt, minf, maxf, tdl;
  REAL8 totalPower;
  char tabname[64];
  INT4 tsec,tnsec;
  SearchSummaryInfo info;

  INITSTATUS (status, "BuildTFCOutput", APPLYSEARCHC);
  ATTATCHSTATUSPTR (status);

  ASSERT(clist, status, APPLYSEARCHH_ENULL, APPLYSEARCHH_MSGENULL);

  output->numOutput = 1 + clist->nclusters;
  
  output->fracRemaining = 0.0;
  output->notFinished = 0;

  outputArray = output->result = (outPut *) LALMalloc( (1 + clist->nclusters) * sizeof(outPut) );

  /* Search Summary */
  dbEntry = NULL;
 
  info.dsoName = "TFCLUSTERS";
  info.inputStartTime.gpsSeconds = t0Sec;
  info.inputStartTime.gpsNanoSeconds = t0NanoSec;
  info.inputEndTime.gpsNanoSeconds = t0NanoSec + (UINT4)(1E9*(t0NanoSec - floor(tDuration)));
  if(info.inputEndTime.gpsNanoSeconds >= 1000000000) {
    UINT4 tmpSec = (UINT4)floor(info.inputEndTime.gpsNanoSeconds / 1000000000.0);
    info.inputEndTime.gpsNanoSeconds -= 1000000000 * tmpSec;
    info.inputEndTime.gpsSeconds = t0Sec + tmpSec + (UINT4)floor(tDuration);
  } else {
    info.inputEndTime.gpsSeconds = t0Sec + (UINT4)floor(tDuration);
  }
  info.inputEndTime.gpsSeconds = t0Sec;
  info.outputStartTime = info.inputStartTime;
  info.outputEndTime = info.inputEndTime;
  info.numEvents = clist->nclusters;
  info.numNodes = numSlaves;

  LALCreateSearchSummaryDataBase( status->statusPtr, &dbEntry, &info ); 
  CHECKSTATUSPTR( status ); 

  outputArray->results = dbEntry;
  outputArray->search = burst;
  outputArray->significant = 1;

  /* Events */

  switch(table) {
  case SNGL_BURST:
    sprintf( tabname, "sngl_burst" );
    break;
  case GDS_TRIGGER:
    sprintf( tabname, "gds_trigger" );
    break;
  default:
    ABORT( status, APPLYSEARCHH_EIERR, APPLYSEARCHH_MSGEIERR);
  }

  for(i=0; i<clist->nclusters; i++) {
    outputArray[i+1].indexNumber = 0;
    outputArray[i+1].search = burst;
    outputArray[i+1].significant    = 1;
    outputArray[i+1].states         = NULL;
    outputArray[i+1].optional       = NULL;


    dbEntry = outputArray[i+1].results = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = NULL;


    if(TFC_BLOB__) {
      /* zeroth entry: event id */
      strcpy( dbEntry->tableName, "sngl_burst");
      sprintf( dbEntry->columnName, "event_id" );

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *)LALMalloc(128 * sizeof(CHAR));
      sprintf(dbEntry->rows.chars,"sngl_burstgroup:sngl_burst:%u",i);
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = strlen(dbEntry->rows.chars);
      
      prev = dbEntry;

      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
    }    

    /* copy first two letters of name for IFO */
    strcpy( dbEntry->tableName, tabname );
    sprintf( dbEntry->columnName, "ifo" );

    dbEntry->type       = char_s_ptr;
    dbEntry->numberRows = 1;
    dbEntry->rows.chars = (CHAR *) LALMalloc( 2 * dbEntry->numberRows * sizeof(CHAR) );
    memcpy(dbEntry->rows.chars, name, 2);
    dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
    *(dbEntry->rowDimensions) = 2;

    prev = dbEntry;
    
    if(table == GDS_TRIGGER) {

      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, tabname );  
      sprintf( dbEntry->columnName, "name" );

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 11 * dbEntry->numberRows * sizeof(CHAR) );
      memcpy(dbEntry->rows.chars, name, 2);
      sprintf(dbEntry->rows.chars, "TFCLUSTERS");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 10;

      prev = dbEntry;

      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, tabname );
      sprintf( dbEntry->columnName, "subtype" );

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( (strlen(name)+1) * dbEntry->numberRows * sizeof(CHAR) );
      strcpy(dbEntry->rows.chars, name);
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = strlen(name);

      prev = dbEntry;
    
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, tabname );
      sprintf( dbEntry->columnName, "priority" );

      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.int4s) = 1; /* ARBITRARY VALUE */

      prev = dbEntry;

      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, tabname );
      sprintf( dbEntry->columnName, "binarydata_length" );

      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.int4s) = 0; 

      prev = dbEntry;
    }
    else {
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, tabname );  
      sprintf( dbEntry->columnName, "search" );

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 11 * dbEntry->numberRows * sizeof(CHAR) );
      memcpy(dbEntry->rows.chars, name, 2);
      sprintf(dbEntry->rows.chars, "TFCLUSTERS");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 10;

      prev = dbEntry;
    }

    mint = maxt = clist->t[i][0];
    minf = maxf = clist->f[i][0];
    totalPower = clist->P[i][0];

    if(!resp) {
      for(j=1; j<clist->sizes[i]; j++) {
	totalPower += clist->P[i][j];
      }
    }
    else {
      for(j=1; j<clist->sizes[i]; j++) {
	/* NOTE: VERIFY THIS!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
	/* resp is assumed to be in (strain/ADC)^2 = 1 / transfer function square */
	/* P is in ADC^2, so total power is strain^2 */
	totalPower += (clist->P[i][j] - spec[clist->f[i][j]]) * resp[clist->f[i][j]];
      }
    }

    for(j=1; j<clist->sizes[i]; j++) {
      if(clist->t[i][j] < mint) mint = clist->t[i][j];
      if(clist->t[i][j] > maxt) maxt = clist->t[i][j];
      if(clist->f[i][j] < minf) minf = clist->f[i][j];
      if(clist->f[i][j] > maxf) maxf = clist->f[i][j];
    }

    /* time */
    tsec = t0Sec + (INT4)floor((REAL4)mint * clist->params->deltaT);
    tnsec = (INT4)floor(1E9*((REAL4)mint * clist->params->deltaT - floor((REAL4)mint * clist->params->deltaT)));
    tnsec += (INT4)t0NanoSec;
    if(tnsec >= 1000000000) {
      tsec++;
      tnsec-=1000000000;
    }

    /* entry: start_time */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;
    

    strcpy( dbEntry->tableName, tabname );
    sprintf( dbEntry->columnName, "start_time" );

    dbEntry->type       = int_4s;
    dbEntry->numberRows = 1;
    dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.int4s) = tsec;

    prev = dbEntry;

    /* entry: start_time_ns */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;

    strcpy( dbEntry->tableName, tabname );
    sprintf( dbEntry->columnName, "start_time_ns" );

    dbEntry->type       = int_4s;
    dbEntry->numberRows = 1;
    dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.int4s) = tnsec;

    prev = dbEntry;

    /* entry: duration */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;

    strcpy( dbEntry->tableName, tabname );
    sprintf( dbEntry->columnName, "duration" );

    dbEntry->type       = real_4;
    dbEntry->numberRows = 1;
    dbEntry->rows.real4 = (REAL4 *) LALMalloc( sizeof(REAL4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.real4) = (REAL4)clist->params->deltaT * (REAL4)(maxt-mint+1);

    prev = dbEntry;

    
    /* entry: central frequency */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;

    strcpy( dbEntry->tableName, tabname );
    switch(table) {
    case SNGL_BURST:
      sprintf( dbEntry->columnName, "central_freq" );
      break;
    case GDS_TRIGGER:
      sprintf( dbEntry->columnName, "frequency" );
      break;
    default:
      ABORT( status, APPLYSEARCHH_EIERR, APPLYSEARCHH_MSGEIERR);
    }

    dbEntry->type       = real_4;
    dbEntry->numberRows = 1;
    dbEntry->rows.real4 = (REAL4 *) LALMalloc( sizeof(REAL4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.real4) = clist->params->flow + (REAL4) (minf + maxf) / (2.0 * (REAL4)clist->params->deltaT);

    prev = dbEntry;

    
    /* entry: bandwidth  */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;

    strcpy( dbEntry->tableName, tabname );
    sprintf( dbEntry->columnName, "bandwidth" );

    dbEntry->type       = real_4;
    dbEntry->numberRows = 1;
    dbEntry->rows.real4 = (REAL4 *) LALMalloc( sizeof(REAL4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.real4) = (REAL4) (maxf - minf + 1) / (REAL4)clist->params->deltaT;

    prev = dbEntry;


    /* entry: integrated power per pixel */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev;

    strcpy( dbEntry->tableName, tabname );
    switch(table) {
    case SNGL_BURST:
      sprintf( dbEntry->columnName, "snr" );
      break;
    case GDS_TRIGGER:
      sprintf( dbEntry->columnName, "significance" );
      break;
    default:
      ABORT( status, APPLYSEARCHH_EIERR, APPLYSEARCHH_MSGEIERR);
    }

    dbEntry->type       = real_4;
    dbEntry->numberRows = 1;
    dbEntry->rows.real4 = (REAL4 *) LALMalloc( sizeof(REAL4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.real4) = (REAL4)totalPower / (REAL4)(clist->sizes[i]);

    prev = dbEntry;


    /* entry: size stored in amplitude */
    dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
    dbEntry->previous = prev; 

    strcpy( dbEntry->tableName, tabname );
    switch(table) {
    case SNGL_BURST:
      sprintf( dbEntry->columnName, "amplitude" );
      break;
    case GDS_TRIGGER:
      sprintf( dbEntry->columnName, "size" );
      break;
    default:
      ABORT( status, APPLYSEARCHH_EIERR, APPLYSEARCHH_MSGEIERR);
    }
  
    dbEntry->type       = real_4;
    dbEntry->numberRows = 1;
    dbEntry->rows.real4 = (REAL4 *) LALMalloc( sizeof(REAL4) );
    dbEntry->rowDimensions = NULL;
    *(dbEntry->rows.real4) = (REAL4)(clist->sizes[i]);


    /***********************************************************/
    /*************************BLOB******************************/
    if(TFC_BLOB__)
    {
      prev = dbEntry;
      
      /* sngl_transdata: event_id */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "event_id" );

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *)LALMalloc(128 * sizeof(CHAR));

      sprintf(dbEntry->rows.chars,"sngl_burstgroup:sngl_burst:%u",i);
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = strlen(dbEntry->rows.chars);

      prev = dbEntry;
      
      
      /* sngl_transdata: event_table */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "event_table" );
      
      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc((1 + strlen(tabname)) * dbEntry->numberRows * sizeof(CHAR) );
      strcpy(dbEntry->rows.chars, tabname);
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = strlen(tabname);
      
      prev = dbEntry;

      /* copy first two letters of name for IFO */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "ifo" );
      
      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 2 * dbEntry->numberRows * sizeof(CHAR) );
      memcpy(dbEntry->rows.chars, name, 2);
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 2;
      
      prev = dbEntry;
      
      /* transdata_name */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "transdata_name");
      
      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 8 * dbEntry->numberRows * sizeof(CHAR) );
      sprintf(dbEntry->rows.chars,"tf data");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 7;
      
      prev = dbEntry;
      
      /* dimensionality */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "dimensions");
      
      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.int4s) = 2; 
      
      prev = dbEntry;
      
      /* number of bins */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "x_bins");
      
      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.int4s) = clist->sizes[i]; 
      
      prev = dbEntry;

      /* time limits */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "x_start");
      dbEntry->type       = real_8;
      dbEntry->numberRows = 1;
      dbEntry->rows.real8 = (REAL8 *) LALMalloc( sizeof(REAL8) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.real8) = t0Sec + 1E-9*(REAL8)t0NanoSec + (REAL8)mint * clist->params->deltaT;
      
      prev = dbEntry;

      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "x_end");
      dbEntry->type       = real_8;
      dbEntry->numberRows = 1;
      dbEntry->rows.real8 = (REAL8 *) LALMalloc( sizeof(REAL8) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.real8) = t0Sec + 1E-9*(REAL8)t0NanoSec + (REAL8)(1+maxt) * clist->params->deltaT;
      
      prev = dbEntry;

      /* units */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "x_units");
      
      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 12 * dbEntry->numberRows * sizeof(CHAR) );
      sprintf(dbEntry->rows.chars,"GPS seconds");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 11;
      
      prev = dbEntry;


      /* number of bins */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "y_bins");
      
      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.int4s) = clist->sizes[i]; 
      
      prev = dbEntry;
      
      /* frequency limits */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "y_start");
      dbEntry->type       = real_8;
      dbEntry->numberRows = 1;
      dbEntry->rows.real8 = (REAL8 *) LALMalloc( sizeof(REAL8) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.real8) = clist->params->flow + (REAL8)minf / (REAL8)clist->params->deltaT;
      
      prev = dbEntry;
      
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "y_end");
      dbEntry->type       = real_8;
      dbEntry->numberRows = 1;
      dbEntry->rows.real8 = (REAL8 *) LALMalloc( sizeof(REAL8) );
      dbEntry->rowDimensions = NULL;
      *(dbEntry->rows.real8) = clist->params->flow + (REAL8)(1+maxf) / (REAL8)clist->params->deltaT;
      
      prev = dbEntry;
      
      /* units */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "y_units");
      
      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 6 * dbEntry->numberRows * sizeof(CHAR) );
      sprintf(dbEntry->rows.chars,"Hertz");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 5;
      
      prev = dbEntry;
      
      /* data_type */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "data_type");

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 8 * dbEntry->numberRows * sizeof(CHAR) );
      sprintf(dbEntry->rows.chars,"tf data");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 7;

      prev = dbEntry;

      /* data_units */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;

      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "data_units");

      dbEntry->type       = char_s_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.chars = (CHAR *) LALMalloc( 10 * dbEntry->numberRows * sizeof(CHAR) );
      sprintf(dbEntry->rows.chars,"composite");
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = 9;

      prev = dbEntry;

      /* length */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "transdata_length");

      dbEntry->type       = int_4s;
      dbEntry->numberRows = 1;
      dbEntry->rows.int4s = (INT4 *) LALMalloc( sizeof(INT4) );
      dbEntry->rowDimensions = NULL;
      tdl = *(dbEntry->rows.int4s) = clist->sizes[i]*(2*sizeof(UINT4) + sizeof(REAL8)); 
    
      if(tdl >= 1000000) {
	ABORT( status, APPLYSEARCHH_EMAXBLOB, APPLYSEARCHH_MSGEMAXBLOB);
      }

      prev = dbEntry;

      /* data (bigEndian) */
      dbEntry = prev->next = (dataBase *) LALMalloc( sizeof(dataBase) );
      dbEntry->previous = prev;
      
      strcpy( dbEntry->tableName, "sngl_transdata");
      sprintf( dbEntry->columnName, "transdata");
      
      dbEntry->type       = char_u_ptr;
      dbEntry->numberRows = 1;
      dbEntry->rows.charu = (UCHAR *) LALMalloc( tdl );
      
      for(j=0; j<clist->sizes[i]; j++) {
	UINT4 tmp = clist->t[i][j] - mint;
#ifdef linux
	endian_swap((char *)(&tmp), sizeof(UINT4), 1);
#endif
	memcpy(dbEntry->rows.charu + j*sizeof(UINT4), &tmp, sizeof(UINT4));
      }
      for(j=0; j<clist->sizes[i]; j++) {
	UINT4 tmp = clist->f[i][j] - minf;
#ifdef linux
	endian_swap((char *)(&tmp), sizeof(UINT4), 1);
#endif
	memcpy(dbEntry->rows.charu + clist->sizes[i]*sizeof(UINT4) + j*sizeof(UINT4), &tmp, sizeof(UINT4));
      }
      for(j=0; j<clist->sizes[i]; j++) {
	REAL8 tmp = clist->P[i][j];
#ifdef linux
	endian_swap((char *)(&tmp), sizeof(REAL8), 1);
#endif
	memcpy(dbEntry->rows.charu + 2*clist->sizes[i]*sizeof(UINT4) + j*sizeof(REAL8), &tmp, sizeof(REAL8));
      }
      
      dbEntry->rowDimensions = (UINT4 *) LALMalloc( sizeof(UINT4) );
      *(dbEntry->rowDimensions) = tdl;
    } /* end of BLOB */


    /* LAST entry */
    dbEntry->next = NULL;
  } /* loop over nclusters */

  DETATCHSTATUSPTR (status);
  RETURN (status);
}


#ifdef linux
void endian_swap(char * pdata, int dsize, int nelements)

{

        int i,j,indx;
        char tempbyte;

        if (dsize <= 1) return;

        for (i=0; i<nelements; i++)
        {
                indx = dsize;
                for (j=0; j<dsize/2; j++)
                {
                        tempbyte = pdata[j];
                        indx = indx - 1;
                        pdata[j] = pdata[indx];
                        pdata[indx] = tempbyte;
                }

                pdata = pdata + dsize;
        }

        return;

}
#endif
